@@ -10,7 +10,7 @@ frontend = optional(
   default={
     'port': 8000,
     'host': '0.0.0.0',
-    'prefix': None
+    'prefix': None,
   }
 )
 
