@@ -1,17 +1,18 @@
+import gevent.monkey; gevent.monkey.patch_all()
+import psycogreen.gevent; psycogreen.gevent.patch_psycopg()
 import datetime
 import json
 import os
+import re
 
 import bottle
 import configurati
 
 from .database import Database
+from .log import initialize as init_logging
 
 
 def main(config):
-  # connect to db
-  db = Database(config.db)
-
   # setup routes
   app = attach_routes(config.db, prefix=config.frontend.prefix)
 
@@ -19,13 +20,19 @@ def main(config):
   app.run(
     port=config.frontend.port,
     host=config.frontend.host,
-    server='tornado',
+    server='gevent',
   )
 
 
 def attach_routes(db, app=None, prefix=None):
   """Attach sqlrest routes to app"""
 
+  # if connector isn't specified, choose one that's asynchronous
+  if db.uri.startswith("mysql://"):
+    db.uri = re.sub("^mysql://", "mysql+mysqlconnector://", db.uri)
+  elif config.uri.startswith("postgresql://"):
+    db.uri = re.sub("^postgresql://", "postgresql+psycopg2://", db.uri)
+
   if prefix is None:
     prefix = ''
 
@@ -137,8 +144,18 @@ def json_escape(o):
 
 
 if __name__ == '__main__':
+  spec_path = os.path.join(
+    os.path.split(__file__)[0],
+    "config.spec.py"
+  )
   if os.path.exists('config.py'):
-    config = configurati.configure(config_path='config.py')
+    config = configurati.configure(
+      config_path='config.py',
+      spec_path=spec_path
+    )
   else:
-    config = configurati.configure()
+    config = configurati.configure(spec_path=spec_path)
+
+  init_logging()
+
   main(config)
